@@ -1,12 +1,12 @@
 """UK specific code."""
-from datetime import datetime
 import logging
+from datetime import datetime
+
 import requests
 
-from ..const import RESPONSE_OK
 from ..classes.programme import Programme
-
-from .const_gb import CHANNEL_IMAGE_URL, PVR_IMAGE_URL, SCHEDULE_URL, LIVE_IMAGE_URL
+from ..const import RESPONSE_OK
+from .const_gb import CHANNEL_IMAGE_URL, LIVE_IMAGE_URL, PVR_IMAGE_URL, SCHEDULE_URL
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -23,10 +23,6 @@ class SkyQCountry:
         """Get EPG data for UK."""
         return self._getData(sid, channelno, epgDate)
 
-    def getTimeEpgData(self, sid, channelno, queryDateFrom, queryDateTo):
-        """Get EPG data for UK."""
-        return self._getData(sid, channelno, queryDateFrom)
-
     def _getData(self, sid, channelno, epgDate):
         epgDateStr = epgDate.strftime("%Y%m%d")
 
